@@ -2,11 +2,8 @@
 Utility scripts which do not strictly belong to any other module.
 """
 
-
 import functools
 
-from pydantic import SecretStr
-
 from .errors import EmptyParametersException
 
 
@@ -22,11 +19,3 @@ def check_empty_parameters(func):
         return func(ref, *args, **kwargs)
 
     return _check
-
-
-def json_defaults(value):
-    """
-    JSON default callback to serialize different types of data.
-    """
-    mapping = {SecretStr: str}
-    return mapping[type(value)](value)
